@@ -1,5 +1,3 @@
-(* $Id: ag_oj_emit.ml 53195 2011-01-28 23:38:12Z martin $ *)
-
 (*
   OCaml code generator for the json format.
 *)
@@ -658,7 +656,8 @@ let rec make_reader p (x : oj_mapping) : Ag_indent.t list =
         in
 	let read_tag =
 	  [
-	    `Line "match Yojson.Safe.start_any_variant p lb with";
+            `Line "Yojson.Safe.read_space p lb;";
+            `Line "match Yojson.Safe.start_any_variant p lb with";
             `Block [
               `Line "| `Edgy_bracket -> (";
               `Block [
@@ -727,8 +726,8 @@ let rec make_reader p (x : oj_mapping) : Ag_indent.t list =
              `Array ->
                let read =
 	         match o with
-                     `List -> "Yojson.Safe.read_list ("
-                   | `Array -> "Yojson.Safe.read_array ("
+                     `List -> "Ag_oj_run.read_list ("
+                   | `Array -> "Ag_oj_run.read_array ("
                in
 	       [
 		 `Line read;
@@ -936,7 +935,7 @@ and make_record_reader p loc a record_kind =
     `Block [
       `Block [
         `Inline check_bits;
-        `Line "x";
+        `Line "Ag_oj_run.identity x";
       ];
       `Line ")";
     ];
